% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mutational.signatures.discovery.R
\name{signaturesAssignment}
\alias{signaturesAssignment}
\title{signaturesAssignment}
\usage{
signaturesAssignment(
  x,
  beta,
  normalize_counts = FALSE,
  sparsify = TRUE,
  verbose = TRUE
)
}
\arguments{
\item{x}{counts matrix for a set of n patients and m categories. These can be, e.g., SBS, MNV, CN or CN counts;
in the case of SBS it would be an n patients x 96 trinucleotides matrix.}

\item{beta}{matrix of the discovered signatures to be used for the assignment.}

\item{normalize_counts}{if true, the input counts matrix x is normalized such that the patients have the same number of mutation.}

\item{sparsify}{boolean; Shall I perform regularization using LASSO?}

\item{verbose}{boolean; Shall I print information messages?}
}
\value{
A list with the discovered signatures. It includes 2 elements:
             alpha: matrix of the discovered exposure values.
             beta: matrix of the discovered signatures.
}
\description{
Perform the assignment of K somatic mutational signatures provided as input to samples given a set of observed counts x.
This function can be used to estimate different types of mutational signatures such as: SBS (single base substitutions) and MNV (multi-nucleotide variant)
(see Degasperi, Andrea, et al. 'Substitution mutational signatures in whole-genome–sequenced cancers in the UK population.' Science 376.6591 (2022): abl9283),
CX (chromosomal instability) (see Drews, Ruben M., et al. 'A pan-cancer compendium of chromosomal instability.' Nature 606.7916 (2022): 976-983) and CN (copy number)
signatures (see Steele, Christopher D., et al. 'Signatures of copy number alterations in human cancer.' Nature 606.7916 (2022): 984-991).
}
\examples{
data(background)
data(patients)
set.seed(12345)
beta <- signaturesDecomposition(x = patients[seq_len(3),],
                               K = 3,
                               background_signature = background,
                               nmf_runs = 2,
                               sparsify = FALSE,
                               num_processes = 1)
set.seed(12345)
res <- signaturesAssignment(x = patients[seq_len(3),], beta = beta$beta[[1]], sparsify = FALSE)

}
